@@ -141,7 +141,7 @@ def NASNet(input_shape=None,
                          'or the path to the weights file to be loaded.')
 
     if weights == 'imagenet' and include_top and classes != 1000:
-        raise ValueError('If using `weights` as ImageNet with `include_top` '
+        raise ValueError('If using `weights` as `"imagenet"` with `include_top` '
                          'as true, `classes` should be 1000')
 
     if (isinstance(input_shape, tuple) and
@@ -247,13 +247,17 @@ def NASNet(input_shape=None,
     # Ensure that the model takes into account
     # any potential predecessors of `input_tensor`.
     if input_tensor is not None:
-        inputs = engine.get_source_inputs(input_tensor)
+        if hasattr(keras_utils, 'get_source_inputs'):
+            get_source_inputs = keras_utils.get_source_inputs
+        else:
+            get_source_inputs = engine.get_source_inputs
+        inputs = get_source_inputs(input_tensor)
     else:
         inputs = img_input
 
     model = models.Model(inputs, x, name='NASNet')
 
-    # load weights
+    # Load weights.
     if weights == 'imagenet':
         if default_size == 224:  # mobile version
             if include_top:
