@@ -12,6 +12,7 @@ from __future__ import division
 from __future__ import print_function
 
 import os
+import warnings
 
 from . import get_keras_submodule
 
@@ -58,16 +59,21 @@ def identity_block(input_tensor, kernel_size, filters, stage, block):
     bn_name_base = 'bn' + str(stage) + block + '_branch'
 
     x = layers.Conv2D(filters1, (1, 1),
+                      kernel_initializer='he_normal',
                       name=conv_name_base + '2a')(input_tensor)
     x = layers.BatchNormalization(axis=bn_axis, name=bn_name_base + '2a')(x)
     x = layers.Activation('relu')(x)
 
     x = layers.Conv2D(filters2, kernel_size,
-                      padding='same', name=conv_name_base + '2b')(x)
+                      padding='same',
+                      kernel_initializer='he_normal',
+                      name=conv_name_base + '2b')(x)
     x = layers.BatchNormalization(axis=bn_axis, name=bn_name_base + '2b')(x)
     x = layers.Activation('relu')(x)
 
-    x = layers.Conv2D(filters3, (1, 1), name=conv_name_base + '2c')(x)
+    x = layers.Conv2D(filters3, (1, 1),
+                      kernel_initializer='he_normal',
+                      name=conv_name_base + '2c')(x)
     x = layers.BatchNormalization(axis=bn_axis, name=bn_name_base + '2c')(x)
 
     x = layers.add([x, input_tensor])
@@ -108,19 +114,24 @@ def conv_block(input_tensor,
     bn_name_base = 'bn' + str(stage) + block + '_branch'
 
     x = layers.Conv2D(filters1, (1, 1), strides=strides,
+                      kernel_initializer='he_normal',
                       name=conv_name_base + '2a')(input_tensor)
     x = layers.BatchNormalization(axis=bn_axis, name=bn_name_base + '2a')(x)
     x = layers.Activation('relu')(x)
 
     x = layers.Conv2D(filters2, kernel_size, padding='same',
+                      kernel_initializer='he_normal',
                       name=conv_name_base + '2b')(x)
     x = layers.BatchNormalization(axis=bn_axis, name=bn_name_base + '2b')(x)
     x = layers.Activation('relu')(x)
 
-    x = layers.Conv2D(filters3, (1, 1), name=conv_name_base + '2c')(x)
+    x = layers.Conv2D(filters3, (1, 1),
+                      kernel_initializer='he_normal',
+                      name=conv_name_base + '2c')(x)
     x = layers.BatchNormalization(axis=bn_axis, name=bn_name_base + '2c')(x)
 
     shortcut = layers.Conv2D(filters3, (1, 1), strides=strides,
+                             kernel_initializer='he_normal',
                              name=conv_name_base + '1')(input_tensor)
     shortcut = layers.BatchNormalization(
         axis=bn_axis, name=bn_name_base + '1')(shortcut)
@@ -186,7 +197,7 @@ def ResNet50(include_top=True,
                          'or the path to the weights file to be loaded.')
 
     if weights == 'imagenet' and include_top and classes != 1000:
-        raise ValueError('If using `weights` as imagenet with `include_top`'
+        raise ValueError('If using `weights` as `"imagenet"` with `include_top`'
                          ' as true, `classes` should be 1000')
 
     # Determine proper input shape
@@ -213,6 +224,7 @@ def ResNet50(include_top=True,
     x = layers.Conv2D(64, (7, 7),
                       strides=(2, 2),
                       padding='valid',
+                      kernel_initializer='he_normal',
                       name='conv1')(x)
     x = layers.BatchNormalization(axis=bn_axis, name='bn_conv1')(x)
     x = layers.Activation('relu')(x)
@@ -247,17 +259,24 @@ def ResNet50(include_top=True,
             x = layers.GlobalAveragePooling2D()(x)
         elif pooling == 'max':
             x = layers.GlobalMaxPooling2D()(x)
+        else:
+            warnings.warn('The output shape of `ResNet50(include_top=False)` '
+                          'has been changed since Keras 2.2.0.')
 
     # Ensure that the model takes into account
     # any potential predecessors of `input_tensor`.
     if input_tensor is not None:
-        inputs = engine.get_source_inputs(input_tensor)
+        if hasattr(keras_utils, 'get_source_inputs'):
+            get_source_inputs = keras_utils.get_source_inputs
+        else:
+            get_source_inputs = engine.get_source_inputs
+        inputs = get_source_inputs(input_tensor)
     else:
         inputs = img_input
     # Create model.
     model = models.Model(inputs, x, name='resnet50')
 
-    # load weights
+    # Load weights.
     if weights == 'imagenet':
         if include_top:
             weights_path = keras_utils.get_file(
